@@ -2,12 +2,32 @@ from types import GeneratorType
 from functools import partial
 from pythonwhat.Reporter import Reporter
 from pythonwhat.Test import Test, TestFail
-from pythonwhat.Feedback import Feedback
+from pythonwhat.Feedback import Feedback, InstructorError
 import copy
 import ast
 
 def multi(*args, state=None):
-    """Run multiple subtests. Return original state (for chaining)."""
+    """Run multiple subtests. Return original state (for chaining).
+
+    Args:
+        state: State instance describing student and solution code. Can be omitted if used with Ex().
+        tests: sub-SCTs that all should pass.
+
+    :Example:
+
+        Suppose we want to verify the following function call: ::
+
+            round(1.2345, ndigits=2)
+
+        The following SCT would verify this, using ``multi`` to
+        'branch out' the state to two sub-SCTs: ::
+
+            Ex().check_function('round').multi(
+                check_args(0).has_equal_value(),
+                check_args('ndigits').has_equal_value()
+            )
+
+    """
     if any(args):
         rep = Reporter.active_reporter
 
@@ -28,16 +48,21 @@ def check_not(*tests, msg, state=None):
 
     Args:
         state: State instance describing student and solution code. Can be omitted if used with Ex().
+        tests: one or more sub-SCTs that all should not pass.
         args: one or more sub-SCTs to run.
+
     :Example:
-        Thh SCT below runs two test_student_typed cases.. ::
+        The SCT below runs two ``has_code`` cases: ::
 
-            Ex().multi(test_student_typed('INNER'), test_student_typed('OUTER'))
+            Ex().check_not(
+                has_code('mean'),
+                has_code('median')
+            )
 
-        If students use INNER (JOIN) or OUTER (JOIN) in their code, this test will fail.
+        If students use ``mean`` or ``median`` anywhere in their code, this SCT will fail.
 
     Note:
-        - This function is currently only tested in working with test_student_typed in the subtests.
+        - This function is currently only tested in working with has_code in the subtests.
         - This function can be thought as a NOT(x OR y OR ...) statement, since all tests it runs must fail
         - This function can be considered a direct counterpart of multi.
 
@@ -56,7 +81,27 @@ def check_not(*tests, msg, state=None):
     return state
 
 def check_or(*tests, state=None):
-    """Test whether at least one SCT passes."""
+    """Test whether at least one SCT passes.
+
+    If all of the tests fail, the feedback of the first test will be presented to the student.
+
+    Args:
+        state: State instance describing student and solution code. Can be omitted if used with Ex().
+        tests: one or more sub-SCTs to run.
+
+    :Example:
+
+        The SCT below tests that the student typed either 'mean' or 'median': ::
+
+            Ex().check_or(
+                has_code('mean'),
+                has_code('median')
+            )
+
+        If the student didn't type either, the feedback message generated by ``has_code(mean)``,
+        the first SCT, will be presented to the student.
+
+    """
 
     rep = Reporter.active_reporter
 
@@ -74,7 +119,24 @@ def check_or(*tests, state=None):
     rep.do_test(Test(first_feedback))
 
 def check_correct(check, diagnose, state=None):
-    """Allows feedback from a diagnostic SCT, only if a check SCT fails. """
+    """Allows feedback from a diagnostic SCT, only if a check SCT fails.
+
+    Args:
+        state: State instance describing student and solution code. Can be omitted if used with Ex().
+        check: An sct chain that must succeed.
+        diagnose: An sct chain to run if the check fails.
+
+    :Example:
+
+        The SCT below tests whether an object is correct. Only if the object is not correct, will
+        the function calling checks be executed ::
+
+            Ex().check_correct(
+                check_object('x').has_equal_value(),
+                check_function('round').check_args(0).has_equal_value()
+            )
+
+    """
     def diagnose_and_check(state=None):
         # use multi twice, since diagnose and check may be lists of tests
         multi(diagnose, state=state)
@@ -184,14 +246,14 @@ def set_context(*args, state=None, **kwargs):
 
     # for now, you can't specify both
     if len(args) > 0 and len(kwargs) > 0:
-        raise ValueError("In set_context() make sure to specify arguments either by position, either by name")
+        raise InstructorError("In `set_context()`, specify arguments either by position, either by name.")
 
     # set args specified by pos -----------------------------------------------
     if args:
         # stop if too many pos args for solution
         if len(args) > len(sol_crnt): 
-            raise IndexError("Too many positional args. There are {} context vals, but tried to set {}"
-                                .format(len(sol_crnt), len(args)))
+            raise InstructorError("Too many positional args. There are {} context vals, but tried to set {}"
+                                  .format(len(sol_crnt), len(args)))
         # set pos args
         upd_sol = sol_crnt.update(dict(zip(sol_crnt.keys(), args)))
         upd_stu = stu_crnt.update(dict(zip(stu_crnt.keys(), args)))
@@ -203,8 +265,8 @@ def set_context(*args, state=None, **kwargs):
     if kwargs:
         # stop if keywords don't match with solution
         if set(kwargs) - set(upd_sol):
-            raise KeyError("Context val names are {}, but tried to set {}"
-                                .format(upd_sol or "none", kwargs.keys()))
+            raise InstructorError("`set_context()` failed: context val names are {}, but you tried to set {}."
+                                  .format(upd_sol or "missing", sorted(list(kwargs.keys()))))
         out_sol = upd_sol.update(kwargs)
         # need to match keys in kwargs with corresponding keys in stu context
         # in case they used, e.g., different loop variable names
